<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns="urn:WebWorks-Help-Books-Schema"
                              xmlns:wwhbooks="urn:WebWorks-Help-Books-Schema"
                              xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                              xmlns:msxsl="urn:schemas-microsoft-com:xslt"
                              xmlns:wwtoc="urn:WebWorks-Engine-TOC-Schema"
                              xmlns:wwlinks="urn:WebWorks-Engine-Links-Schema"
                              xmlns:wwmode="urn:WebWorks-Engine-Mode"
                              xmlns:wwfiles="urn:WebWorks-Engine-Files-Schema"
                              xmlns:wwdoc="urn:WebWorks-Document-Schema"
                              xmlns:wwsplits="urn:WebWorks-Engine-Splits-Schema"
                              xmlns:wwproject="urn:WebWorks-Publish-Project"
                              xmlns:wwpage="urn:WebWorks-Page-Template-Schema"
                              xmlns:wwlocale="urn:WebWorks-Locale-Schema"
                              xmlns:wwprogress="urn:WebWorks-XSLT-Extension-Progress"
                              xmlns:wwlog="urn:WebWorks-XSLT-Extension-Log"
                              xmlns:wwfilesystem="urn:WebWorks-XSLT-Extension-FileSystem"
                              xmlns:wwuri="urn:WebWorks-XSLT-Extension-URI"
                              xmlns:wwstring="urn:WebWorks-XSLT-Extension-StringUtilities"
                              xmlns:wwfilesext="urn:WebWorks-XSLT-Extension-Files"
                              xmlns:wwprojext="urn:WebWorks-XSLT-Extension-Project"
                              xmlns:wwexsldoc="urn:WebWorks-XSLT-Extension-Document"
                              exclude-result-prefixes="xsl msxsl wwtoc wwlinks wwmode wwfiles wwdoc wwsplits wwproject wwpage wwlocale wwprogress wwlog wwfilesystem wwuri wwstring wwfilesext wwprojext wwexsldoc"
>
 <xsl:param name="GlobalInput" />
 <xsl:param name="GlobalPipelineName" />
 <xsl:param name="GlobalProject" />
 <xsl:param name="GlobalFiles" />
 <xsl:param name="ParameterType" />
 <xsl:param name="ParameterCategory" />
 <xsl:param name="ParameterUse" />
 <xsl:param name="ParameterDeploy" />


 <xsl:output encoding="UTF-8" indent="yes" />
 <xsl:namespace-alias stylesheet-prefix="wwhbooks" result-prefix="#default" />
 <xsl:strip-space elements="*" />


 <xsl:include href="wwformat:Transforms/wwhelp_context.xsl" />


 <xsl:key name="wwproject-formatconfigurations-by-targetid" match="wwproject:FormatConfiguration" use="@TargetID" />


 <xsl:variable name="GlobalActionChecksum">
  <xsl:variable name="VarTransformChecksums">
   <xsl:value-of select="concat(wwuri:AsFilePath('wwtransform:self'), ':', wwfilesystem:GetChecksum(wwuri:AsFilePath('wwtransform:self')))" />
   <xsl:value-of select="concat(',', wwuri:AsFilePath('wwformat:Transforms/wwhelp_context.xsl'), ':', wwfilesystem:GetChecksum(wwuri:AsFilePath('wwformat:Transforms/wwhelp_context.xsl')))" />
  </xsl:variable>
  <xsl:value-of select="wwstring:MD5Checksum($VarTransformChecksums)" />
 </xsl:variable>


 <xsl:template match="/">
  <wwfiles:Files version="1.0">

   <!-- Groups -->
   <!--        -->
   <xsl:variable name="VarProjectGroups" select="$GlobalProject/wwproject:Project/wwproject:Groups/wwproject:Group" />
   <xsl:variable name="VarIgnore1Start" select="wwprogress:Start(count($VarProjectGroups) + 1)" />

   <xsl:for-each select="$VarProjectGroups">
    <xsl:variable name="VarProjectGroup" select="." />

    <xsl:variable name="VarIgnore2Start" select="wwprogress:Start(1)" />

    <!-- Determine group output directory path -->
    <!--                                       -->
    <xsl:variable name="VarGroupOutputDirectoryPath" select="wwfilesystem:Combine(wwprojext:GetTargetOutputDirectoryPath(), $VarProjectGroup/@Name)" />

    <xsl:variable name="VarPath" select="wwfilesystem:Combine($VarGroupOutputDirectoryPath, 'wwhelp/books.xml')" />

    <!-- Transform -->
    <!--           -->
    <xsl:variable name="VarUpToDate" select="wwfilesext:UpToDate($VarPath, $VarProjectGroup/@ChangeID, $VarProjectGroup/@GroupID, '', $GlobalActionChecksum)" />
    <xsl:if test="not($VarUpToDate)">
     <xsl:variable name="VarResultAsXML">
      <xsl:call-template name="Books">
       <xsl:with-param name="ParamProjectGroup" select="$VarProjectGroup" />
      </xsl:call-template>
     </xsl:variable>
     <xsl:variable name="VarResult" select="msxsl:node-set($VarResultAsXML)" />
     <xsl:variable name="VarWriteResult" select="wwexsldoc:Document($VarResult, $VarPath, 'utf-8', 'xml', '1.0', 'yes')" />
    </xsl:if>

    <!-- Report Files -->
    <!--              -->
    <wwfiles:File path="{$VarPath}" type="{$ParameterType}" checksum="{wwfilesystem:GetChecksum($VarPath)}" projectchecksum="{$VarProjectGroup/@ChangeID}" groupID="{$VarProjectGroup/@GroupID}" documentID="" actionchecksum="{$GlobalActionChecksum}" category="{$ParameterCategory}" use="{$ParameterUse}" deploy="{$ParameterDeploy}" />

    <xsl:variable name="VarIgnore2End" select="wwprogress:End()" />
   </xsl:for-each>

   <!-- Merge -->
   <!--       -->
   <xsl:variable name="VarIgnore3Start" select="wwprogress:Start(1)" />
   <xsl:if test="count($VarProjectGroups) &gt; 1">
    <xsl:for-each select="$GlobalProject[1]">
     <xsl:variable name="VarFormatConfiguration" select="key('wwproject-formatconfigurations-by-targetid', wwprojext:GetFormatID())[1]" />
     <xsl:variable name="VarMergeSettings" select="$VarFormatConfiguration/wwproject:MergeSettings" />

     <xsl:variable name="VarMergePath" select="wwfilesystem:Combine(wwprojext:GetTargetOutputDirectoryPath(), 'wwhelp/books.xml')" />

     <!-- Call template -->
     <!--               -->
     <xsl:variable name="VarUpToDate" select="wwfilesext:UpToDate($VarMergePath, concat($GlobalProject/wwproject:Project/@ChangeID, ':', count($VarProjectGroups)), '', '', $GlobalActionChecksum)" />
     <xsl:if test="not($VarUpToDate)">
      <xsl:variable name="VarResultAsXML">
       <xsl:call-template name="MergeBooks">
        <xsl:with-param name="ParamMergeSettings" select="$VarMergeSettings" />
       </xsl:call-template>
      </xsl:variable>
      <xsl:variable name="VarResult" select="msxsl:node-set($VarResultAsXML)" />
      <xsl:variable name="VarWriteResult" select="wwexsldoc:Document($VarResult, $VarMergePath, wwprojext:GetFormatSetting('encoding', 'utf-8'), 'xml', '1.0', 'yes')" />
     </xsl:if>

     <wwfiles:File path="{$VarMergePath}" type="{$ParameterType}" checksum="{wwfilesystem:GetChecksum($VarMergePath)}" projectchecksum="{concat($GlobalProject/wwproject:Project/@ChangeID, ':', count($VarProjectGroups))}" groupID="" documentID="" actionchecksum="{$GlobalActionChecksum}" category="{$ParameterCategory}" use="{$ParameterUse}" deploy="{$ParameterDeploy}" />
    </xsl:for-each>
   </xsl:if>
   <xsl:variable name="VarIgnore3End" select="wwprogress:End()" />

   <xsl:variable name="VarIgnore1End" select="wwprogress:End()" />

  </wwfiles:Files>
 </xsl:template>


 <xsl:template name="Books">
  <xsl:param name="ParamProjectGroup" />

  <xsl:variable name="VarTitle">
   <xsl:call-template name="WWHelpTitle">
    <xsl:with-param name="ParamProject" select="$GlobalProject" />
    <xsl:with-param name="ParamGroupID" select="$ParamProjectGroup/@GroupID" />
   </xsl:call-template>
  </xsl:variable>

  <wwhbooks:WebWorksHelpBooks version="5.0" name="{$VarTitle}" expandalltopentries="false" showbooks="false">
   <wwhbooks:Book directory="." />
  </wwhbooks:WebWorksHelpBooks>
 </xsl:template>


 <xsl:template name="MergeBooks">
  <xsl:param name="ParamMergeSettings" />

  <xsl:variable name="VarMergeTitle">
   <xsl:choose>
    <xsl:when test="string-length($ParamMergeSettings/@Title) &gt; 0">
     <xsl:value-of select="$ParamMergeSettings/@Title" />
    </xsl:when>

    <xsl:otherwise>
     <xsl:value-of select="wwprojext:GetFormatName()" />
    </xsl:otherwise>
   </xsl:choose>
  </xsl:variable>

  <wwhbooks:WebWorksHelpBooks version="5.0" name="{$VarMergeTitle}" expandalltopentries="false" showbooks="true">
   <xsl:apply-templates select="$ParamMergeSettings" mode="wwmode:mergebooks" />
  </wwhbooks:WebWorksHelpBooks>
 </xsl:template>


 <xsl:template match="wwproject:TOC" mode="wwmode:mergebooks">
  <xsl:param name="ParamTOC" select="." />

  <wwhbooks:BookGroup name="{$ParamTOC/@Name}">
   <xsl:apply-templates select="$ParamTOC/*" mode="wwmode:mergebooks" />
  </wwhbooks:BookGroup>
 </xsl:template>


 <xsl:template match="wwproject:MergeGroup" mode="wwmode:mergebooks">
  <xsl:param name="ParamMergeGroup" select="." />

  <xsl:for-each select="$GlobalProject[1]">
   <wwhbooks:Book directory="{wwuri:EscapeData(wwprojext:GetGroupName($ParamMergeGroup/@GroupID))}" />
  </xsl:for-each>
 </xsl:template>
</xsl:stylesheet>
